@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -25,22 +28,34 @@ ssd_plot_cdf <- function(x, ...) {
 
 #' @describeIn ssd_plot_cdf Plot CDF for fitdists object
 #' @inheritParams params
+#' @param average A flag specifying whether to provide model averaged values as opposed to a value for each distribution or if NA provides model averaged and individual values.
 #' @param ... Additional arguments passed to [ssd_plot()].
 #' @export
 #' @examples
 #' fits <- ssd_fit_dists(ssddata::ccme_boron)
 #' ssd_plot_cdf(fits)
-ssd_plot_cdf.fitdists <- function(x, average = FALSE, delta = 7, ...) {
-  pred <- ssd_hc(x, percent = 1:99, average = average, delta = delta)
+#' ssd_plot_cdf(fits, average = NA)
+ssd_plot_cdf.fitdists <- function(x, average = FALSE, delta = 9.21, ...) {
+  chk_scalar(average)
+  chk_logical(average)
+
+  if (!is.na(average)) {
+    pred <- ssd_hc(x, proportion = 1:99 / 100, average = average, delta = delta)
+  } else {
+    pred <- ssd_hc(x, proportion = 1:99 / 100, average = FALSE, delta = delta)
+    pred_ave <- ssd_hc(x, proportion = 1:99 / 100, average = TRUE, delta = delta)
+    pred <- dplyr::bind_rows(pred, pred_ave)
+  }
   data <- ssd_data(x)
   cols <- .cols_fitdists(x)
-  
-  linetype <- if(length(unique(pred$dist)) > 1) "dist" else NULL
-  linecolor <- linetype
-  pred$percent <- round(pred$percent) # not sure why needed
 
-  ssd_plot(data = data, pred = pred, left = cols$left, right = cols$right,
-           ci = FALSE, hc = NULL, linetype = linetype, linecolor = linecolor, ...) +
+  linetype <- if (length(unique(pred$dist)) > 1) "dist" else NULL
+  linecolor <- linetype
+
+  ssd_plot(
+    data = data, pred = pred, left = cols$left, right = cols$right,
+    ci = FALSE, hc = NULL, linetype = linetype, linecolor = linecolor, ...
+  ) +
     labs(linetype = "Distribution", color = "Distribution")
 }
 
@@ -49,20 +64,21 @@ ssd_plot_cdf.fitdists <- function(x, average = FALSE, delta = 7, ...) {
 #' @export
 #' @seealso [`estimates.fitdists()`] and [`ssd_match_moments()`]
 #' @examples
-#' 
+#'
 #' ssd_plot_cdf(list(
 #'   llogis = c(locationlog = 2, scalelog = 1),
-#'   lnorm = c(meanlog = 2, sdlog = 2))
-#' )
+#'   lnorm = c(meanlog = 2, sdlog = 2)
+#' ))
 ssd_plot_cdf.list <- function(x, ...) {
-  pred <- ssd_hc(x, percent = 1:99)
+  pred <- ssd_hc(x, proportion = 1:99 / 100)
   data <- data.frame(Conc = numeric(0))
 
-  linetype <- if(length(unique(pred$dist)) > 1) "dist" else NULL
+  linetype <- if (length(unique(pred$dist)) > 1) "dist" else NULL
   linecolor <- linetype
-  pred$percent <- round(pred$percent) # not sure why needed
-  
-  ssd_plot(data = data, pred = pred,
-           ci = FALSE, hc = NULL, linetype = linetype, linecolor = linecolor, ...) +
+
+  ssd_plot(
+    data = data, pred = pred,
+    ci = FALSE, hc = NULL, linetype = linetype, linecolor = linecolor, ...
+  ) +
     labs(color = "Distribution", linetype = "Distribution")
 }
