@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -17,6 +20,7 @@ graphics::plot
 
 #' @export
 plot.fitdists <- function(x, ...) {
-  lifecycle::deprecate_warn("0.3.4", "plot.fitdists()", "autoplot.fitdists()")
+  lifecycle::deprecate_stop("0.3.4", "plot.fitdists()", "autoplot.fitdists()")
+  chk_unused(...)
   autoplot(x)
 }
