@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -13,28 +16,31 @@
 #    limitations under the License.
 
 #' Comma and Significance Formatter
-#' 
-#' By default the numeric vectors are first rounded to three significant figures.
-#' Then scales::comma is only applied to values greater than or equal to 1000
-#' to ensure that labels are permitted to have different numbers of decimal places.
 #'
 #' @param x A numeric vector to format.
-#' @param ... Additional arguments passed to [scales::comma].
 #' @inheritParams params
 #' @return A character vector.
+#' @seealso [ssd_label_comma()]
 #' @export
 #' @examples
-#' comma_signif(c(0.1, 1, 10, 1000))
-#' scales::comma(c(0.1, 1, 10, 1000))
-comma_signif <- function(x, digits = 3, ...) {
-  if(vld_used(...)) {
-    deprecate_soft("0.3.3", "comma_signif(...)")
-  }
-  
+#' \dontrun{
+#' comma_signif(c(0.1, 1, 10, 1000, 10000))
+#' }
+comma_signif <- function(x, digits = 3, ..., big.mark = ",") {
+  lifecycle::deprecate_soft(
+    "2.0.0", "comma_signif()", "ssd_label_comma()",
+    details = "Use `labels = ssd_label_comma()` instead of `labels = comma_signif` when constructing `ggplot` objects."
+  )
+
+  chk_numeric(x)
+  chk_number(digits)
+  chk_string(big.mark)
+  chk_unused(...)
+
   x <- signif(x, digits = digits)
   y <- as.character(x)
   bol <- !is.na(x) & as.numeric(x) >= 1000
-  y[bol] <- comma(x[bol], ...)
+  y[bol] <- stringr::str_replace_all(y[bol], "(\\d{1,1})(\\d{3,3}(?<=\\.|$))", paste0("\\1", big.mark, "\\2"))
   y
 }
 
@@ -53,7 +59,7 @@ ssd_ecd <- function(x, ties.method = "first") {
 #' Empirical Cumulative Density for Species Sensitivity Data
 #'
 #' @inheritParams params
-#' @return A numeric vector of the empirical cumulative density for the rows 
+#' @return A numeric vector of the empirical cumulative density for the rows
 #' in data.
 #' @seealso [`ssd_ecd()`] and [`ssd_data()`]
 #' @export
@@ -61,12 +67,14 @@ ssd_ecd <- function(x, ties.method = "first") {
 #' @examples
 #' ssd_ecd_data(ssddata::ccme_boron)
 ssd_ecd_data <- function(
-  data, left = "Conc", right = left, bounds = c(left = 1, right = 1)) {
+    data, left = "Conc", right = left, bounds = c(left = 1, right = 1)) {
   .chk_data(data, left, right)
   .chk_bounds(bounds)
-  
-  if(!nrow(data)) return(double(0))
-  
+
+  if (!nrow(data)) {
+    return(double(0))
+  }
+
   data <- process_data(data, left = left, right = right)
   data <- bound_data(data, bounds)
   x <- rowMeans(log(data[c("left", "right")]))
@@ -74,9 +82,9 @@ ssd_ecd_data <- function(
 }
 
 #' Sort Species Sensitivity Data
-#' 
+#'
 #' Sorts Species Sensitivity Data by empirical cumulative density (ECD).
-#' 
+#'
 #' Useful for sorting data before using [geom_ssdpoint()] and [geom_ssdsegment()]
 #' to construct plots for censored data with `stat = identity` to
 #' ensure order is the same for the various components.
@@ -91,5 +99,5 @@ ssd_ecd_data <- function(
 #' ssd_sort_data(ssddata::ccme_boron)
 ssd_sort_data <- function(data, left = "Conc", right = left) {
   ecd <- ssd_ecd_data(data, left = left, right = right)
-  data[order(ecd),,drop = FALSE]
+  data[order(ecd), , drop = FALSE]
 }
